@@ -36,14 +36,6 @@ def step_impl(context, value):
     click(context, find_button(context, get_value(context,value)))
 
 
-@when(u'je sélectionne la valeur "{value}" du champ "{field}"')
-@when(u'que je sélectionne la valeur "{value}" du champ "{field}"')
-def step_impl(context, value, field):
-    value = get_value(context, value)
-    field = get_value(context, field)
-    click(context, find_option(context, field, value))
-
-
 @when(u'je clique sur le lien "{value}"')
 @when(u'que je clique sur le lien "{value}"')
 def step_impl(context, value):
@@ -58,6 +50,14 @@ def step_impl(context, value):
     click(context, find_element(context, value))
 
 
+@when(u'je sélectionne la valeur "{value}" du champ "{field}"')
+@when(u'que je sélectionne la valeur "{value}" du champ "{field}"')
+def step_impl(context, value, field):
+    value = get_value(context, value)
+    field = get_value(context, field)
+    click(context, find_option(context, field, value))
+
+
 @when(u'je vide le champ "{field}"')
 @when(u'que je vide le champ "{field}"')
 @when(u'je tape "" dans le champ "{field}"')
@@ -123,6 +123,7 @@ def select_file(context, filename, field):
         element.send_keys(filepath)
 
 
+# Testing step
 @when(u'je tente le fichier "{filename}"')
 @when(u'que je tente le fichier "{filename}"')
 def select_file(context, filename):
@@ -133,6 +134,7 @@ def select_file(context, filename):
         pyperclip.paste()
 
 
+# Testing step
 @when(u'je sélectionne le fichier "{filename}" dans le champ invisible "{field}"')
 @when(u'que je sélectionne le fichier "{filename}" dans le champ invisible "{field}"')
 def step_impl(context, filename, field):
@@ -438,21 +440,18 @@ def step_impl(context, field):
 
 
 @then(u'je clique sur le bouton "{value}"')
-@then(u'que je clique sur le bouton "{value}"')
 def step_impl(context, value):
     value = get_value(context, value)
     click(context, find_button(context, value, False))
 
 
 @then(u'je clique sur le lien "{value}"')
-@then(u'que je clique sur le lien "{value}"')
 def step_impl(context, value):
     value = get_value(context, value)
     click(context, find_link(context, value, False))
 
 
 @then(u'un élément contenant "{value}" existe')
-@then(u'qu\'un élément contenant "{value}" existe')
 def step_impl(context, value):
     find_element(context, get_value(context, value))
 
